"""Used for getting powerflow data."""

from typing import Any

from aiohttp import ClientSession


async def get_powerflow(
    session: ClientSession, power_station_id: str, token: str
) -> Any:
    """Get the powerflow data."""

    url = "https://au.semsportal.com/api/v2/PowerStation/GetPowerflow"
    headers = {"Content-Type": "application/json", "Token": token}
    body = {"PowerStationId": power_station_id}

    response = await session.post(url, headers=headers, json=body)
    response_data = await response.json()

    return response_data["data"]



"""Used for login logic."""

from typing import Any

from aiohttp import ClientSession


async def login_to_sems(session: ClientSession, account: str, pwd: str) -> Any:
    """Login to the SEMS portal."""
    url = "https://www.semsportal.com/api/v1/Common/CrossLogin"
    headers = {
        "Content-Type": "application/json",
        "Token": '{"version":"v2.1.0","client":"ios","language":"en"}',
    }
    body = {"account": account, "pwd": pwd}

    response = await session.post(url, headers=headers, json=body)
    response_data = await response.json()

    return response_data["data"]



"""Used for getting sems charts data."""

from datetime import datetime
from typing import Any

from aiohttp import ClientSession


async def get_plant_power_chart(
    session: ClientSession, plant_id: str, token: str, targetDate: datetime = datetime.now()
) -> Any:
    """Retrieve powerplant chart data."""
    formatted_date = targetDate.strftime("%Y-%m-%d")
    url = "https://au.semsportal.com/api/v2/Charts/GetPlantPowerChart"
    headers = {"Content-Type": "application/json", "Token": token}
    body = {"id": plant_id, "date": formatted_date, "full_script": False}

    response = await session.post(url, headers=headers, json=body, timeout=10000)
    response_data = await response.json()

    return response_data["data"]
